@@ -169,7 +169,9 @@ class Mobject(object):
         return self
 
     @property
-    def animate(self):
+    # Although it is incorrect to say that the return type is T,
+    # it helps with the code editor giving autocomplete for the methods on the animation builder
+    def animate(self: T) -> T:
         # Borrowed from https://github.com/ManimCommunity/manim/
         return _AnimationBuilder(self)
 
@@ -698,7 +700,12 @@ class Mobject(object):
     def get_family_updaters(self) -> list[Updater]:
         return list(it.chain(*[sm.get_updaters() for sm in self.get_family()]))
 
-    def add_updater(self, update_function: Updater, index: int | None = None, call_updater: bool = True):
+    def add_updater(
+        self: T,
+        update_function: Callable[[T, float], None | T] | Callable[[T], None | T],
+        index: int | None = None,
+        call_updater: bool = True,
+    ):
         if "dt" in get_parameters(update_function):
             updater_list = self.time_based_updaters
         else:
